@@ -222,6 +222,8 @@ static void controller_handle_action (GameAction action)
 	  board_gtk_undo_move ();
 	  break;
 
+	case GAME_ACTION_NEW:
+	case GAME_ACTION_CONTINUE:
 	default:
 	  break;
 	}
@@ -374,7 +376,7 @@ static gboolean on_key_press_event (GObject *widget, GdkEventKey *event,
   return FALSE;
 }
 
-static void game_init ()
+static void game_init (void)
 {
   g_return_if_fail (app != NULL);
 
@@ -488,7 +490,7 @@ static void update_statistics (void)
 
 typedef struct
 {
-  gchar *cmd;
+  const gchar *cmd;
   gboolean enabled;
 } CmdEnable;
 
@@ -583,7 +585,6 @@ void update_menu_item_state (void)
 -------------------------------------------------------------- */
 static AtomixApp *create_gui (GApplication *app_instance)
 {
-  AtomixApp *app;
   gchar *ui_path;
   GtkBuilder *builder;
   GtkWidget *stats_grid;
@@ -628,9 +629,10 @@ static AtomixApp *create_gui (GApplication *app_instance)
 
   if (gtk_application_prefers_app_menu (GTK_APPLICATION (app_instance))) {
     GMenu * menu = G_MENU (gtk_builder_get_object (builder, "app-menu"));
+    GtkWidget *menubar = GTK_WIDGET (gtk_builder_get_object (builder, "menubar"));
+
     gtk_application_set_app_menu (GTK_APPLICATION (app->app_instance), G_MENU_MODEL (menu));
-//    GtkWidget *menubar = GTK_WIDGET (gtk_builder_get_object (builder, "menubar"));
-//    gtk_widget_set_visible (menubar, FALSE);
+    gtk_widget_set_visible (menubar, FALSE);
   }
 
   g_object_unref (builder);
